@@ -661,7 +661,13 @@ def create_test_yml(ctx, tool, run_tests, output, force, no_prompts):
     the required `test.yml` file based on the output files.
     """
     try:
-        meta_builder = nf_core.modules.ModulesTestYmlBuilder(tool, run_tests, output, force, no_prompts)
+        meta_builder = nf_core.modules.ModulesTestYmlBuilder(
+            module_name=tool,
+            run_tests=run_tests,
+            test_yml_output_path=output,
+            force_overwrite=force,
+            no_prompts=no_prompts,
+        )
         meta_builder.run()
     except (UserWarning, LookupError) as e:
         log.critical(e)
