@@ -29,7 +29,7 @@ def module_changes(module_lint_object, module):
         shutil.copytree(module.module_dir, tempdir)
         try:
             new_lines = ModulesDiffer.try_apply_patch(
-                module.module_name, module_lint_object.modules_repo.fullname, module.patch_path, tempdir, reverse=True
+                module.module_name, module_lint_object.modules_repo.repo_path, module.patch_path, tempdir, reverse=True
             )
             for file, lines in new_lines.items():
                 with open(tempdir / file, "w") as fh:
