@@ -2,11 +2,13 @@ import filecmp
 import logging
 import os
 import shutil
+from importlib.resources import path
 from pathlib import Path
 
 import git
+import rich
 import rich.progress
-from git.exc import GitCommandError
+from git.exc import GitCommandError, InvalidGitRepositoryError
 
 import nf_core.modules.module_utils
 import nf_core.modules.modules_json
@@ -15,7 +17,7 @@ from nf_core.utils import NFCORE_DIR
 log = logging.getLogger(__name__)
 
 # Constants for the nf-core/modules repo used throughout the module files
-NF_CORE_MODULES_NAME = "nf-core/modules"
+NF_CORE_MODULES_NAME = "nf-core"
 NF_CORE_MODULES_REMOTE = "https://github.com/nf-core/modules.git"
 NF_CORE_MODULES_DEFAULT_BRANCH = "master"
 
@@ -125,16 +127,17 @@ class ModulesRepo(object):
 
         self.remote_url = remote_url
 
-        self.fullname = nf_core.modules.module_utils.path_from_remote(self.remote_url)
+        self.repo_path = nf_core.modules.module_utils.path_from_remote(self.remote_url)
+        self.fullname = nf_core.modules.module_utils.repo_full_name_from_remote(self.remote_url)
 
         self.setup_local_repo(remote_url, branch, hide_progress)
 
         # Verify that the repo seems to be correctly configured
-        if self.fullname != NF_CORE_MODULES_NAME or self.branch:
+        if self.repo_path != NF_CORE_MODULES_NAME or self.branch:
             self.verify_branch()
 
         # Convenience variable
-        self.modules_dir = os.path.join(self.local_repo_dir, "modules")
+        self.modules_dir = os.path.join(self.local_repo_dir, "modules", self.repo_path)
 
         self.avail_module_names = None
 
@@ -150,55 +153,64 @@ class ModulesRepo(object):
         Sets self.repo
         """
         self.local_repo_dir = os.path.join(NFCORE_DIR, self.fullname)
-        if not os.path.exists(self.local_repo_dir):
-            try:
-                pbar = rich.progress.Progress(
-                    "[bold blue]{task.description}",
-                    rich.progress.BarColumn(bar_width=None),
-                    "[bold yellow]{task.fields[state]}",
-                    transient=True,
-                    disable=hide_progress,
-                )
-                with pbar:
-                    self.repo = git.Repo.clone_from(
-                        remote,
-                        self.local_repo_dir,
-                        progress=RemoteProgressbar(pbar, self.fullname, self.remote_url, "Cloning"),
+        try:
+            if not os.path.exists(self.local_repo_dir):
+                try:
+                    pbar = rich.progress.Progress(
+                        "[bold blue]{task.description}",
+                        rich.progress.BarColumn(bar_width=None),
+                        "[bold yellow]{task.fields[state]}",
+                        transient=True,
+                        disable=hide_progress or os.environ.get("HIDE_PROGRESS", None) is not None,
                     )
-                ModulesRepo.update_local_repo_status(self.fullname, True)
-            except GitCommandError:
-                raise LookupError(f"Failed to clone from the remote: `{remote}`")
-            # Verify that the requested branch exists by checking it out
-            self.setup_branch(branch)
-        else:
-            self.repo = git.Repo(self.local_repo_dir)
+                    with pbar:
+                        self.repo = git.Repo.clone_from(
+                            remote,
+                            self.local_repo_dir,
+                            progress=RemoteProgressbar(pbar, self.fullname, self.remote_url, "Cloning"),
+                        )
+                    ModulesRepo.update_local_repo_status(self.fullname, True)
+                except GitCommandError:
+                    raise LookupError(f"Failed to clone from the remote: `{remote}`")
+                # Verify that the requested branch exists by checking it out
+                self.setup_branch(branch)
+            else:
+                self.repo = git.Repo(self.local_repo_dir)
 
-            if ModulesRepo.no_pull_global:
-                ModulesRepo.update_local_repo_status(self.fullname, True)
-            # If the repo is already cloned, fetch the latest changes from the remote
-            if not ModulesRepo.local_repo_synced(self.fullname):
-                pbar = rich.progress.Progress(
-                    "[bold blue]{task.description}",
-                    rich.progress.BarColumn(bar_width=None),
-                    "[bold yellow]{task.fields[state]}",
-                    transient=True,
-                    disable=hide_progress,
-                )
-                with pbar:
-                    self.repo.remotes.origin.fetch(
-                        progress=RemoteProgressbar(pbar, self.fullname, self.remote_url, "Pulling")
+                if ModulesRepo.no_pull_global:
+                    ModulesRepo.update_local_repo_status(self.fullname, True)
+                # If the repo is already cloned, fetch the latest changes from the remote
+                if not ModulesRepo.local_repo_synced(self.fullname):
+                    pbar = rich.progress.Progress(
+                        "[bold blue]{task.description}",
+                        rich.progress.BarColumn(bar_width=None),
+                        "[bold yellow]{task.fields[state]}",
+                        transient=True,
+                        disable=hide_progress or os.environ.get("HIDE_PROGRESS", None) is not None,
                     )
-                ModulesRepo.update_local_repo_status(self.fullname, True)
+                    with pbar:
+                        self.repo.remotes.origin.fetch(
+                            progress=RemoteProgressbar(pbar, self.fullname, self.remote_url, "Pulling")
+                        )
+                    ModulesRepo.update_local_repo_status(self.fullname, True)
 
-            # Before verifying the branch, fetch the changes
-            # Verify that the requested branch exists by checking it out
-            self.setup_branch(branch)
+                # Before verifying the branch, fetch the changes
+                # Verify that the requested branch exists by checking it out
+                self.setup_branch(branch)
 
-            # Now merge the changes
-            tracking_branch = self.repo.active_branch.tracking_branch()
-            if tracking_branch is None:
-                raise LookupError(f"There is no remote tracking branch '{self.branch}' in '{self.remote_url}'")
-            self.repo.git.merge(tracking_branch.name)
+                # Now merge the changes
+                tracking_branch = self.repo.active_branch.tracking_branch()
+                if tracking_branch is None:
+                    raise LookupError(f"There is no remote tracking branch '{self.branch}' in '{self.remote_url}'")
+                self.repo.git.merge(tracking_branch.name)
+        except (GitCommandError, InvalidGitRepositoryError) as e:
+            log.error(f"[red]Could not set up local cache of modules repository:[/]\n{e}\n")
+            if rich.prompt.Confirm.ask(f"[violet]Delete local cache '{self.local_repo_dir}' and try again?"):
+                log.info(f"Removing '{self.local_repo_dir}'")
+                shutil.rmtree(self.local_repo_dir)
+                self.setup_local_repo(remote, branch, hide_progress)
+            else:
+                raise LookupError("Exiting due to error with local modules git repo")
 
     def setup_branch(self, branch):
         """
@@ -210,7 +222,7 @@ class ModulesRepo(object):
         """
         if branch is None:
             # Don't bother fetching default branch if we're using nf-core
-            if self.fullname == NF_CORE_MODULES_NAME:
+            if self.remote_url == NF_CORE_MODULES_REMOTE:
                 self.branch = "master"
             else:
                 self.branch = self.get_default_branch()
@@ -235,7 +247,7 @@ class ModulesRepo(object):
         try:
             self.checkout_branch()
         except GitCommandError:
-            raise LookupError(f"Branch '{self.branch}' not found in '{self.fullname}'")
+            raise LookupError(f"Branch '{self.branch}' not found in '{self.remote_url}'")
 
     def verify_branch(self):
         """
@@ -243,7 +255,7 @@ class ModulesRepo(object):
         """
         dir_names = os.listdir(self.local_repo_dir)
         if "modules" not in dir_names:
-            err_str = f"Repository '{self.fullname}' ({self.branch}) does not contain the 'modules/' directory"
+            err_str = f"Repository '{self.remote_url}' ({self.branch}) does not contain the 'modules/' directory"
             if "software" in dir_names:
                 err_str += (
                     ".\nAs of nf-core/tools version 2.0, the 'software/' directory should be renamed to 'modules/'"
@@ -309,11 +321,11 @@ class ModulesRepo(object):
 
         # Check if the module exists in the branch
         if not self.module_exists(module_name, checkout=False):
-            log.error(f"The requested module does not exists in the '{self.branch}' of {self.fullname}'")
+            log.error(f"The requested module does not exists in the branch '{self.branch}' of {self.remote_url}'")
             return False
 
         # Copy the files from the repo to the install folder
-        shutil.copytree(self.get_module_dir(module_name), os.path.join(install_dir, module_name))
+        shutil.copytree(self.get_module_dir(module_name), Path(install_dir, module_name))
 
         # Switch back to the tip of the branch
         self.checkout_branch()
@@ -362,7 +374,7 @@ class ModulesRepo(object):
             ( dict ): Iterator of commit SHAs and associated (truncated) message
         """
         self.checkout_branch()
-        module_path = os.path.join("modules", module_name)
+        module_path = os.path.join("modules", self.repo_path, module_name)
         commits = self.repo.iter_commits(max_count=depth, paths=module_path)
         commits = ({"git_sha": commit.hexsha, "trunc_message": commit.message.partition("\n")[0]} for commit in commits)
         return commits
@@ -398,7 +410,7 @@ class ModulesRepo(object):
                 date_obj = commit.committed_datetime
                 date = str(date_obj.date())
                 return message, date
-        raise LookupError(f"Commit '{sha}' not found in the '{self.fullname}'")
+        raise LookupError(f"Commit '{sha}' not found in the '{self.remote_url}'")
 
     def get_avail_modules(self, checkout=True):
         """
