@@ -10,7 +10,7 @@ from nf_core.modules.module_utils import ModuleException
 def test_modules_bump_versions_single_module(self):
     """Test updating a single module"""
     # Change the bpipe/test version to an older version
-    main_nf_path = os.path.join(self.nfcore_modules, "modules", "bpipe", "test", "main.nf")
+    main_nf_path = os.path.join(self.nfcore_modules, "modules", "nf-core", "bpipe", "test", "main.nf")
     with open(main_nf_path, "r") as fh:
         content = fh.read()
     new_content = re.sub(r"bioconda::star=\d.\d.\d\D?", r"bioconda::star=2.6.1d", content)
@@ -39,7 +39,7 @@ def test_modules_bump_versions_fail(self):
 def test_modules_bump_versions_fail_unknown_version(self):
     """Fail because of an unknown version"""
     # Change the bpipe/test version to an older version
-    main_nf_path = os.path.join(self.nfcore_modules, "modules", "bpipe", "test", "main.nf")
+    main_nf_path = os.path.join(self.nfcore_modules, "modules", "nf-core", "bpipe", "test", "main.nf")
     with open(main_nf_path, "r") as fh:
         content = fh.read()
     new_content = re.sub(r"bioconda::bpipe=\d.\d.\d\D?", r"bioconda::bpipe=xxx", content)
