@@ -10,15 +10,22 @@ import unittest
 import nf_core.create
 import nf_core.modules
 
-from .utils import GITLAB_URL, OLD_TRIMGALORE_SHA
+from .utils import (
+    GITLAB_BRANCH_TEST_BRANCH,
+    GITLAB_BRANCH_TEST_OLD_SHA,
+    GITLAB_DEFAULT_BRANCH,
+    GITLAB_URL,
+    OLD_TRIMGALORE_BRANCH,
+    OLD_TRIMGALORE_SHA,
+)
 
 
 def create_modules_repo_dummy(tmp_dir):
     """Create a dummy copy of the nf-core/modules repo"""
 
     root_dir = os.path.join(tmp_dir, "modules")
-    os.makedirs(os.path.join(root_dir, "modules"))
-    os.makedirs(os.path.join(root_dir, "tests", "modules"))
+    os.makedirs(os.path.join(root_dir, "modules", "nf-core"))
+    os.makedirs(os.path.join(root_dir, "tests", "modules", "nf-core"))
     os.makedirs(os.path.join(root_dir, "tests", "config"))
     with open(os.path.join(root_dir, "tests", "config", "pytest_modules.yml"), "w") as fh:
         fh.writelines(["test:", "\n  - modules/test/**", "\n  - tests/modules/test/**"])
@@ -26,7 +33,7 @@ def create_modules_repo_dummy(tmp_dir):
         fh.writelines(["repository_type: modules", "\n"])
 
     # bpipe is a valid package on bioconda that is very unlikely to ever be added to nf-core/modules
-    module_create = nf_core.modules.ModuleCreate(root_dir, "bpipe/test", "@author", "process_medium", False, False)
+    module_create = nf_core.modules.ModuleCreate(root_dir, "bpipe/test", "@author", "process_single", False, False)
     module_create.create()
 
     return root_dir
@@ -50,10 +57,26 @@ class TestModules(unittest.TestCase):
         self.mods_install = nf_core.modules.ModuleInstall(self.pipeline_dir, prompt=False, force=True)
         self.mods_install_alt = nf_core.modules.ModuleInstall(self.pipeline_dir, prompt=True, force=True)
         self.mods_install_old = nf_core.modules.ModuleInstall(
-            self.pipeline_dir, prompt=False, force=False, sha=OLD_TRIMGALORE_SHA
+            self.pipeline_dir,
+            prompt=False,
+            force=False,
+            sha=OLD_TRIMGALORE_SHA,
+            remote_url=GITLAB_URL,
+            branch=OLD_TRIMGALORE_BRANCH,
+        )
+        self.mods_install_trimgalore = nf_core.modules.ModuleInstall(
+            self.pipeline_dir, prompt=False, force=True, remote_url=GITLAB_URL, branch=OLD_TRIMGALORE_BRANCH
         )
         self.mods_install_gitlab = nf_core.modules.ModuleInstall(
-            self.pipeline_dir, prompt=False, force=True, remote_url=GITLAB_URL
+            self.pipeline_dir, prompt=False, force=True, remote_url=GITLAB_URL, branch=GITLAB_DEFAULT_BRANCH
+        )
+        self.mods_install_gitlab_old = nf_core.modules.ModuleInstall(
+            self.pipeline_dir,
+            prompt=False,
+            force=True,
+            remote_url=GITLAB_URL,
+            branch=GITLAB_BRANCH_TEST_BRANCH,
+            sha=GITLAB_BRANCH_TEST_OLD_SHA,
         )
 
         # Set up remove objects
@@ -72,7 +95,7 @@ class TestModules(unittest.TestCase):
     def test_modulesrepo_class(self):
         """Initialise a modules repo object"""
         modrepo = nf_core.modules.ModulesRepo()
-        assert modrepo.fullname == "nf-core/modules"
+        assert modrepo.repo_path == "nf-core"
         assert modrepo.branch == "master"
 
     ############################################
@@ -133,7 +156,6 @@ class TestModules(unittest.TestCase):
         test_mod_json_create,
         test_mod_json_create_with_patch,
         test_mod_json_dump,
-        test_mod_json_get_git_url,
         test_mod_json_get_module_version,
         test_mod_json_module_present,
         test_mod_json_repo_present,
